;;;###autoload
(package-provide 'ruby-modes
		 :version 1.01
		 :type 'regular)
